@@ -1,9 +1,8 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 """
 This module implements an emulator abstraction layer.
 """
 from __future__ import annotations
+
 from typing import Dict, List, Any, Generic, TypeVar, Optional, Union
 from typing import TYPE_CHECKING
 
@@ -12,20 +11,22 @@ from enum import IntFlag
 from functools import cached_property, partial
 
 from refinery.lib.executable import align, Arch, ET, BO, Executable, ExecutableCodeBlob
-from refinery.lib.tools import NoLogging
 from refinery.lib.vfs import VirtualFileSystem
 from refinery.lib.intervals import IntIntervalUnion
-from refinery.lib.exceptions import MissingModule
+
+from refinery.lib.shared import (
+    unicorn as uc,
+    icicle as ic,
+    speakeasy as se,
+)
 
 if TYPE_CHECKING:
-    from capstone import Cs
     from speakeasy import Speakeasy as Se
     from speakeasy.common import CodeHook, Hook as SeHook
     from speakeasy.memmgr import MemMap
     from unicorn import Uc
     from icicle import Icicle as Ic
 else:
-    class Cs: pass
     class Uc: pass
     class Ic: pass
     class Se: pass
@@ -36,27 +37,6 @@ _E = TypeVar('_E')
 _R = TypeVar('_R')
 
 
-try:
-    with NoLogging():
-        import unicorn as uc
-except ImportError:
-    uc = MissingModule('unicorn')
-try:
-    import speakeasy.profiler as se_profiler
-    import speakeasy.windows.objman as se_objman
-    import speakeasy as se
-except ImportError:
-    se = MissingModule('speakeasy-emulator')
-try:
-    import icicle as ic
-except ImportError:
-    ic = MissingModule('icicle-emu')
-try:
-    import capstone as cs
-except ImportError:
-    cs = MissingModule('capstone')
-
-
 class EmulationError(Exception):
     """
     Base class for any exceptions raised by emulators.
@@ -91,7 +71,9 @@ class Register(Generic[_R]):
         self.code = code
         self.size = size
 
-    def __eq__(self, other: Register):
+    def __eq__(self, other):
+        if not isinstance(other, Register):
+            return False
         return self.code == other.code and self.size == other.size
 
     def __hash__(self):
@@ -136,13 +118,15 @@ class Emulator(ABC, Generic[_E, _R, _T]):
     ):
         if isinstance(data, Executable):
             exe = data
-        try:
-            exe = Executable.Load(data, base)
-        except ValueError:
-            exe = ExecutableCodeBlob(data, base, arch)
-            raw = True
-        else:
             raw = False
+        else:
+            try:
+                exe = Executable.Load(data, base)
+            except ValueError:
+                exe = ExecutableCodeBlob(data, base, arch or Arch.X32)
+                raw = True
+            else:
+                raw = False
 
         self.exe = exe
         self.raw = raw
@@ -198,6 +182,8 @@ class Emulator(ABC, Generic[_E, _R, _T]):
         self._memorymap = IntIntervalUnion()
         self.state = state
         self._reset()
+        for rd in self.exe.relocations():
+            self.mem_write_int(rd.address, rd.value, rd.size)
 
     def step(self, address: int, count: int = 1) -> int:
         """
@@ -255,6 +241,24 @@ class Emulator(ABC, Generic[_E, _R, _T]):
         self.push(tp)
         self.emulate(function, tp)
 
+    def mem_read_int(self, address: int, size: Optional[int] = None):
+        """
+        Read an integer from memory at the given address. The default for the size parameter is
+        the pointer size of the emulated executable.
+        """
+        if size is None:
+            size = self.exe.pointer_size_in_bytes
+        return int.from_bytes(self.mem_read(address, size), self.exe.byte_order().value)
+
+    def mem_write_int(self, address: int, value: int, size: Optional[int] = None):
+        """
+        Read an integer from memory at the given address. The default for the size parameter is
+        the pointer size of the emulated executable.
+        """
+        if size is None:
+            size = self.exe.pointer_size_in_bytes
+        return self.mem_write(address, value.to_bytes(size, self.exe.byte_order().value))
+
     @abstractmethod
     def _reset(self):
         """
@@ -797,8 +801,8 @@ class IcicleEmulator(RawMetalEmulator[Ic, str, _T]):
 
         try:
             arch = {
-                Arch.X32   : 'i686',
-                Arch.X64   : 'x86_64',
+                Arch.X32: 'i686',
+                Arch.X64: 'x86_64',
             }[exe.arch()]
         except KeyError:
             arch = None
@@ -808,9 +812,6 @@ class IcicleEmulator(RawMetalEmulator[Ic, str, _T]):
         if self.hooked(Hook.ApiCall):
             raise NotImplementedError(F'{self.__class__.__name__} cannot hook API calls.')
 
-        if self.hooks & Hook.Memory:
-            raise NotImplementedError(U'Icicle does not support memory hooks yet.')
-
         self.icicle = ice = ic.Icicle(arch)
         self.regmap = {reg.casefold(): val[1] for reg, val in ice.reg_list().items()}
 
@@ -824,42 +825,85 @@ class IcicleEmulator(RawMetalEmulator[Ic, str, _T]):
         self._single_step = False
 
     def _emulate(self, start: int, end: Optional[int] = None):
-        dasm = self.disassembler()
-        code = False
         RS = ic.RunStatus
-        emu = self.icicle
+        MP = ic.MemoryProtection
+        ice = self.icicle
 
-        if self.hooked(Hook.CodeExecute):
-            code = True
-            step = partial(emu.step, 1)
+        code_hooked = self.hooked(Hook.CodeExecute)
+        mm_e_hooked = self.hooked(Hook.MemoryError)
+        mm_w_hooked = self.hooked(Hook.MemoryWrite)
+        mm_r_hooked = self.hooked(Hook.MemoryRead)
+
+        halt = self._single_step
+        dasm = self.exe.disassembler()
+        dasm.detail = True
+
+        if code_hooked or halt:
+            step = partial(ice.step, 1)
         elif end is not None:
-            step = partial(emu.run_until, end)
+            step = partial(ice.run_until, end)
         else:
-            step = emu.run
+            step = ice.run
 
         self.ip = ip = start
+        mprotect = []
+        cb_write = None
+        retrying = 0
 
         while True:
-            if code:
-                op = next(dasm.disasm(self.exe[ip:ip + 12], ip, 1))
-                self.hook_code_execute(emu, ip, op._raw.size, self.state)
+            insn = None
+            self.ip = ip
 
-            status = step()
-
-            if status == RS.InstructionLimit:
+            if code_hooked and not retrying:
+                insn = next(dasm.disasm(self.mem_read(ip, 20), 1))
+                self.hook_code_execute(ice, ip, insn.size, self.state)
+            if mprotect:
+                ice.mem_protect(*mprotect[-1], MP.ExecuteReadWrite)
+            if (status := step()) == RS.InstructionLimit:
+                for p in mprotect:
+                    ice.mem_protect(*p, MP.ExecuteOnly)
+                if cb_write:
+                    addr, size = cb_write
+                    value = self.mem_read_int(addr, size)
+                    if self.hook_mem_write(ice, 0, addr, size, value, self.state) is False:
+                        break
+                    cb_write = None
+                mprotect.clear()
+                retrying = 0
                 ip = self.ip
-                continue
-
-            if status in (
+            elif status in (
                 RS.Breakpoint,
                 RS.Halt,
                 RS.Killed,
             ):
                 break
-            if status == RS.UnhandledException:
-                raise EmulationError(emu.exception_code.name)
-            if status != RS.Running:
+            elif status == RS.UnhandledException:
+                insn = insn or next(dasm.disasm(self.mem_read(ip, 20), 1))
+                size = max((op.size for op in insn.operands), default=insn.addr_size)
+                EC = ic.ExceptionCode
+                ea = ice.exception_value
+                ec = ice.exception_code
+                if ec in (EC.ReadUnmapped, EC.WriteUnmapped) and mm_e_hooked:
+                    if self.hook_mem_error(ice, 0, ea, size, 0, self.state) is not False:
+                        retrying += 1
+                        continue
+                elif ec == EC.ReadPerm and mm_r_hooked:
+                    value = self.mem_read_int(ea, size)
+                    if self.hook_mem_read(ice, 0, ea, size, value, self.state) is not False:
+                        mprotect.append((ea, size))
+                        retrying += 1
+                        continue
+                elif ec == EC.WritePerm and mm_w_hooked:
+                    cb_write = (ea, size)
+                    mprotect.append(cb_write)
+                    retrying += 1
+                    continue
+                else:
+                    raise EmulationError(ec.name)
+            elif status != RS.Running:
                 raise EmulationError(status.name)
+            if halt:
+                break
 
     def halt(self):
         self.icicle.add_breakpoint(self.ip)
@@ -871,10 +915,8 @@ class IcicleEmulator(RawMetalEmulator[Ic, str, _T]):
 
     def _map(self, address: int, size: int):
         MP = ic.MemoryProtection
-        if self.hooked(Hook.MemoryRead):
-            perm = MP.ExecuteRead
-        elif self.hooked(Hook.MemoryWrite):
-            perm = MP.ExecuteRead
+        if self.hooks & Hook.MemoryAccess:
+            perm = MP.ExecuteOnly
         else:
             perm = MP.ExecuteReadWrite
         return self.icicle.mem_map(address, size, perm)
@@ -1110,7 +1152,7 @@ class SpeakeasyEmulator(Emulator[Se, str, _T]):
             inner.stack_base, stack_addr = inner.alloc_stack(self.stack_size)
             inner.set_func_args(inner.stack_base, inner.return_hook)
 
-            run = se_profiler.Run()
+            run = se.profiler.Run()
             run.type = 'thread'
             run.start_addr = start
             run.instr_cnt = 0
@@ -1119,14 +1161,14 @@ class SpeakeasyEmulator(Emulator[Se, str, _T]):
             inner.add_run(run)
 
             if not (p := inner.init_container_process()):
-                p = se_objman.Process(self)
+                p = se.windows.objman.Process(self)
 
             inner.processes.append(p)
             inner.curr_process = p
             if mm := inner.get_address_map(start):
                 mm.set_process(inner.curr_process)
 
-            t = se_objman.Thread(inner, stack_base=inner.stack_base, stack_commit=self.stack_size)
+            t = se.windows.objman.Thread(inner, stack_base=inner.stack_base, stack_commit=self.stack_size)
 
             inner.om.objects.update({t.address: t})
             inner.curr_process.threads.append(t)
