@@ -1,8 +1,8 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 """
 A cross-platform interface to libmagic.
 """
+from __future__ import annotations
+
 try:
     from winmagic import magic
 except ModuleNotFoundError:
