@@ -1,5 +1,3 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 R"""
 Inside a frame (see `refinery.lib.frame`), all chunks that are processed by refinery units have a
 dictionary of metadata attached to them. This dictionary implements chunk-local variables which can
@@ -159,11 +157,11 @@ class CustomStringRepresentation(abc.ABC):
 
 _INDEX = 'index'
 
-_PRINT_SAFE = set(string.printable.encode('latin1')) - set(b'|<>&\t\n\r\x0B\x0B')
+_PRINT_SAFE = set(string.printable.encode('latin1')) - set(b'|<>\t\n\r\v')
 if os.name == 'nt':
     _PRINT_SAFE -= set(b'^"')
 else:
-    _PRINT_SAFE -= set(b'*?\'"')
+    _PRINT_SAFE -= set(b'&*?\'"')
 _PRINT_SAFE = bytes(_PRINT_SAFE)
 _IS_PRINT_SAFE = bytearray(256)
 for p in _PRINT_SAFE:
@@ -848,6 +846,10 @@ class LazyMetaOracle(metaclass=_LazyMetaMeta):
             or key in self.derivations
         )
 
+    def clear(self):
+        self.current.clear()
+        self.tempval.clear()
+
     def __len__(self):
         return len(self.current) + len(self.tempval)
 
