@@ -1,8 +1,8 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 """
 A wrapper module to read local data resources.
 """
+from __future__ import annotations
+
 from importlib import resources
 
 import sys
