@@ -1,10 +1,9 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 """
 Miscellaneous helper functions.
 """
+from __future__ import annotations
+
 import datetime
-import functools
 import inspect
 import itertools
 import logging
@@ -14,10 +13,11 @@ import io
 import warnings
 import re
 
-from typing import ByteString, Callable, Generator, Iterable, Optional, Tuple, TypeVar
+from typing import Callable, Generator, Iterable, Optional, Tuple, TypeVar, Any, Type
 from math import log
 from enum import IntFlag, Enum
 
+from refinery.lib.types import ByteStr
 
 _T = TypeVar('_T')
 
@@ -119,7 +119,7 @@ def documentation(unit):
     Certain pdoc3-specific reference strings are removed.
     """
     import re
-    docs = inspect.getdoc(unit)
+    docs = inspect.getdoc(unit) or ''
     docs = re.sub(R'`refinery\.(?:\w+\.)*(\w+)`', R'\1', docs)
     return docs.replace('`', '')
 
@@ -189,7 +189,7 @@ def autoinvoke(method: Callable[..., _T], keywords: dict) -> _T:
     return method(*posargs, *varargs, **kwdargs)
 
 
-def entropy_fallback(data: ByteString) -> float:
+def entropy_fallback(data: ByteStr) -> float:
     """
     This method is called by `refinery.lib.tools.entropy` when the `numpy` module is not available.
     It computes the shannon entropy of the input byte string and is written in pure Python.
@@ -202,7 +202,7 @@ def entropy_fallback(data: ByteString) -> float:
     return 0.0 + -sum(p * log(p, 2) for p in S if p) / 8.0
 
 
-def entropy(data: ByteString) -> float:
+def entropy(data: ByteStr) -> float:
     """
     Computes the entropy of `data` over the alphabet of all bytes.
     """
@@ -218,7 +218,7 @@ def entropy(data: ByteString) -> float:
     return 0.0 - (numpy.log2(prob) * prob).sum() / 8.0
 
 
-def index_of_coincidence(data: bytearray) -> float:
+def index_of_coincidence(data: ByteStr) -> float:
     """
     Computes the index of coincidence of `data` over the alphabet of all bytes.
     """
@@ -230,7 +230,9 @@ def index_of_coincidence(data: bytearray) -> float:
     try:
         import numpy
     except ImportError:
-        C = [data.count(b) for b in range(0x100)]
+        C = [0] * 0x100
+        for b in data:
+            C[b] += 1
     else:
         C = numpy.histogram(
             numpy.frombuffer(data, dtype=numpy.uint8),
@@ -258,12 +260,24 @@ def isbuffer(obj) -> bool:
         return False
 
 
+def asbuffer(obj) -> Optional[memoryview]:
+    """
+    Attempts to acquire a memoryview of the given object. This works for bytes and bytearrays, or
+    memoryview objects themselves. The return value is `None` for objects that do not support the
+    buffer protocol.
+    """
+    try:
+        return memoryview(obj)
+    except TypeError:
+        return None
+
+
 def splitchunks(
-    data: ByteString,
+    data: ByteStr,
     size: int,
     step: Optional[int] = None,
     truncate: bool = False
-) -> Iterable[ByteString]:
+) -> Iterable[ByteStr]:
     """
     Split `data` into chunks of size `size`. The cursor advances by `step` bytes after extracting a
     block, the default value for `step` is equal to `size`. The boolean parameter `truncate`
@@ -285,7 +299,7 @@ def splitchunks(
         yield chunk
 
 
-def make_buffer_mutable(data: ByteString):
+def make_buffer_mutable(data: ByteStr):
     """
     Returns a mutable version of the input data. Already mutable inputs are returned
     as themselves, i.e. no copy operation occurs in these cases.
@@ -309,13 +323,6 @@ def infinitize(it):
     return it
 
 
-try:
-    cached_property = functools.cached_property
-except AttributeError:
-    def cached_property(p):
-        return property(functools.lru_cache(maxsize=1)(p))
-
-
 class NoLogging:
     """
     A context manager to prevent various unwanted kinds of logging messages to appear.
@@ -360,6 +367,7 @@ class NoLogging:
             logging.disable(logging.NOTSET)
         if self.mode & NoLogging.Mode.WARNING:
             warnings.resetwarnings()
+            assert isinstance(warnings.filters, list)
             warnings.filters[:] = self._warning_filters
         if self.mode & NoLogging.Mode.STD_ERR:
             sys.stderr.close()
@@ -595,3 +603,10 @@ def nopdoc(obj: object):
     pdoc: dict = sys.modules[obj.__module__].__dict__.setdefault('__pdoc__', {})
     pdoc[obj.__qualname__] = False
     return obj
+
+
+def convert(x: _T | Any, t: Type[_T]) -> _T:
+    """
+    Convert the given object `x` to the type `t`.
+    """
+    return x if isinstance(x, t) else t(x) # type:ignore
