@@ -1,5 +1,3 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 """
 This package contains all refinery units. To write an executable refinery unit,
 it is sufficient to write a class that inherits from `refinery.units.Unit` and
@@ -176,15 +174,14 @@ from typing import (
     List,
     Optional,
     Callable,
+    Collection,
     Mapping,
-    ClassVar,
     Tuple,
     Any,
     Generator,
     cast,
     overload,
     no_type_check,
-    get_type_hints,
     TYPE_CHECKING,
 )
 
@@ -201,6 +198,7 @@ from refinery.lib.frame import generate_frame_header, Framed, Chunk, MAGIC, MSIZ
 from refinery.lib.structures import MemoryFile
 from refinery.lib.environment import LogLevel, Logger, environment, logger
 from refinery.lib.types import ByteStr
+from refinery.lib.dependencies import dependency_accessor
 
 from refinery.lib.exceptions import (
     RefineryCriticalException,
@@ -215,11 +213,12 @@ if TYPE_CHECKING:
     from io import BufferedReader, BufferedWriter
 
     DataType = TypeVar('DataType', bound=ByteStr)
-    ProcType = Callable[['Unit', ByteStr], Optional[Union[DataType, Iterable[DataType]]]]
+    ProcType = Callable[['Unit', Chunk], Optional[Union[DataType, Iterable[DataType]]]]
 
-    ByteIO = MemoryFile[ByteStr]
+    ByteIO = MemoryFile[DataType]
 
     _T = TypeVar('_T')
+    _F = TypeVar('_F', bound=Callable)
     _B = TypeVar('_B', bound=Union[BufferedWriter, ByteIO, BinaryIO])
     _E = TypeVar('_E', bound=Enum)
 
@@ -600,7 +599,9 @@ class Arg(Argument):
             assert isinstance(bound, tuple)
             lower, upper = bound
             nt = nt[lower:upper]
-        return cls(*args, group=group, help=help, dest=dest, type=nt, metavar=metavar or 'N')
+        if metavar is cls.omit:
+            metavar = 'N'
+        return cls(*args, group=group, help=help, dest=dest, type=nt, metavar=metavar)
 
     @classmethod
     def Option(
@@ -627,7 +628,7 @@ class Arg(Argument):
         help    : Union[Type[omit], str] = omit,
         metavar : Union[Type[omit], str] = omit,
         dest    : Union[Type[omit], str] = omit,
-        type    : Type = str,
+        type    : Union[Type, Callable] = str,
         nargs   : Union[Type[omit], int, str] = omit,
         group   : Optional[str] = None,
     ):
@@ -705,7 +706,7 @@ class Arg(Argument):
             while symbols is not False:
                 try:
                     annotation = eval(annotation, symbols)
-                except NameError:
+                except (NameError, TypeError):
                     if symbols is not None or module is None:
                         break
                     try:
@@ -856,21 +857,11 @@ class ArgumentSpecification(OrderedDict):
 
 def _UnitProcessorBoilerplate(operation: ProcType[ByteStr]) -> ProcType[Chunk]:
     @wraps(operation)
-    def wrapped(self: Unit, data: ByteStr) -> Optional[Union[Chunk, Iterable[Chunk]]]:
-        ChunkType = Chunk
+    def wrapped(self: Unit, data: Optional[ByteStr]) -> Optional[Union[Chunk, Iterable[Chunk]]]:
         if data is None:
-            data = B''
-        typespec = get_type_hints(operation)
-        typespec.pop('return', None)
-        if typespec and len(typespec) == 1:
-            SpecType = next(iter(typespec.values()))
-            if isinstance(SpecType, str):
-                try: SpecType = eval(SpecType)
-                except Exception: pass
-            if isinstance(SpecType, type):
-                ChunkType = SpecType
-        if not isinstance(data, ChunkType):
-            data = ChunkType(data)
+            data = Chunk()
+        elif not isinstance(data, Chunk):
+            data = Chunk(data)
         result = operation(self, data)
         if isinstance(result, Chunk):
             return result
@@ -909,6 +900,10 @@ class MissingFunction:
     def __call__(*_, **__):
         raise NotImplementedError('A non-invertible unit was operated in reverse.')
 
+    @classmethod
+    def Wrap(cls, _: _F) -> _F:
+        return cast('_F', cls())
+
 
 class Executable(ABCMeta):
     """
@@ -1262,14 +1257,14 @@ class UnitBase(metaclass=Executable, abstract=True):
     """
 
     @abc.abstractmethod
-    def process(self, data: ByteStr) -> Union[Optional[ByteStr], Iterable[ByteStr]]:
+    def process(self, data: Chunk, /) -> None | ByteStr | Iterable[ByteStr]:
         """
         This routine is overridden by children of `refinery.units.Unit` to define how
         the unit processes a given chunk of binary data.
         """
 
-    @MissingFunction
-    def reverse(self, data: ByteStr) -> Union[Optional[ByteStr], Iterable[ByteStr]]:
+    @MissingFunction.Wrap
+    def reverse(self, data: Chunk, /) -> Union[Optional[ByteStr], Iterable[ByteStr]]:
         """
         If this routine is overridden by children of `refinery.units.Unit`, then it must
         implement an operation that reverses the `refinery.units.Unit.process` operation.
@@ -1279,7 +1274,7 @@ class UnitBase(metaclass=Executable, abstract=True):
 
     @classmethod
     @abc.abstractmethod
-    def handles(cls, data: ByteStr) -> Optional[bool]:
+    def handles(cls, data: bytearray | Chunk) -> Optional[bool]:
         """
         This tri-state routine returns `True` if the unit is certain that it can process the
         given input data, and `False` if it is convinced of the opposite. `None` is returned
@@ -1287,7 +1282,7 @@ class UnitBase(metaclass=Executable, abstract=True):
         """
 
     @abc.abstractmethod
-    def filter(self, inputs: Iterable[Chunk]) -> Iterable[Chunk]:
+    def filter(self, chunks: Iterable[Chunk]) -> Iterable[Chunk]:
         """
         Receives an iterable of `refinery.lib.frame.Chunk`s and yields only those that
         should be processed. The default implementation returns the iterator without
@@ -1304,16 +1299,6 @@ class UnitBase(metaclass=Executable, abstract=True):
         """
 
 
-class requirement(property):
-    """
-    An empty descendant of the builtin `property` class that is used to distinguish import
-    requirements on units from other properties. When `refinery.units.Unit.Requires` is used to
-    decorate a member function as an import, this member function becomes an instance of this
-    class.
-    """
-    pass
-
-
 class Unit(UnitBase, abstract=True):
     """
     The base class for all refinery units. It implements a small set of globally
@@ -1393,48 +1378,11 @@ class Unit(UnitBase, abstract=True):
         pass
 
     @staticmethod
-    def Requires(distribution: str, *_buckets: str):
-
-        class Requirement(requirement):
-            dependency: ClassVar[str] = distribution
-            required: ClassVar[bool] = not _buckets
-
-            def __init__(self, importer: Callable):
-                super().__init__(importer)
-                self.module = None
-
-            def __set_name__(self, unit: Type[Unit], name: str):
-                if self.required:
-                    bucket = unit.required_dependencies
-                    if bucket is None:
-                        unit.required_dependencies = bucket = set()
-                    buckets = [bucket]
-                else:
-                    optmap = unit.optional_dependencies
-                    if optmap is None:
-                        unit.optional_dependencies = optmap = {}
-                    buckets = [optmap.setdefault(name, set()) for name in _buckets]
-                for bucket in buckets:
-                    bucket.add(self.dependency)
-
-            def __get__(self, unit: Optional[Type[Unit]], tp: Optional[Type[Executable]] = None):
-                if self.module is not None:
-                    return self.module
-                try:
-                    self.module = module = cast(Callable, self.fget)()
-                except ImportError as E:
-                    deps = unit and unit.optional_dependencies or {}
-                    args = set()
-                    for v in deps.values():
-                        args.update(v)
-                    raise RefineryImportMissing(self.dependency, *args) from E
-                except Exception as E:
-                    raise AttributeError(F'module import for distribution "{distribution}" failed: {E!s}')
-                else:
-                    return module
-
-        Requirement.__qualname__ = F'Requirement({distribution!r})'
-        return Requirement
+    def Requires(distribution: str, _buckets: Collection[str] = (), more: Optional[str] = None):
+        """
+        Proxy to `refinery.lib.dependencies.dependency_accessor`.
+        """
+        return dependency_accessor(distribution, _buckets, more)
 
     @property
     def is_reversible(self) -> bool:
@@ -1542,6 +1490,8 @@ class Unit(UnitBase, abstract=True):
             raise exception
         elif isinstance(exception, RefineryImportMissing):
             self.log_fail(F'dependency {exception.missing} is missing; run pip install {exception.install}')
+            if more := exception.more:
+                self.log_fail(more)
         elif isinstance(exception, RefineryException):
             self.log_fail(exception.args[0])
         else:
@@ -1604,10 +1554,10 @@ class Unit(UnitBase, abstract=True):
         self._framed = Framed(
             normalized_action,
             self.source,
-            self.args.nesting,
-            self.args.squeeze,
             self.filter,
             self.finish,
+            self.args.nesting,
+            self.args.squeeze,
             self.console
         )
         return self._framed
@@ -1615,11 +1565,11 @@ class Unit(UnitBase, abstract=True):
     def finish(self) -> Iterable[Chunk]:
         yield from ()
 
-    def filter(self, inputs: Iterable[Chunk]) -> Iterable[Chunk]:
-        return inputs
+    def filter(self, chunks: Iterable[Chunk]) -> Iterable[Chunk]:
+        return chunks
 
     @classmethod
-    def handles(cls, data: ByteStr) -> Optional[bool]:
+    def handles(cls, data: bytearray | Chunk) -> Optional[bool]:
         return None
 
     def reset(self):
@@ -2008,18 +1958,30 @@ class Unit(UnitBase, abstract=True):
         return B''
 
     @classmethod
-    def labelled(cls, ___br___data: Union[Chunk, ByteStr], **meta) -> Chunk:
+    @overload
+    def labelled(cls, ___br___data: None, **meta) -> None:
+        ...
+
+    @classmethod
+    @overload
+    def labelled(cls, ___br___data: Chunk | ByteStr, **meta) -> Chunk:
+        ...
+
+    @classmethod
+    def labelled(cls, ___br___data: Chunk | ByteStr | None, **meta) -> Chunk | None:
         """
         This class method can be used to label a chunk of binary output with metadata. This
         metadata will be visible inside pipeline frames, see `refinery.lib.frame`.
         """
-        if not isinstance(___br___data, Chunk):
+        if ___br___data is None:
+            return None
+        elif not isinstance(___br___data, Chunk):
             ___br___data = Chunk(___br___data, meta=meta)
         elif meta:
             ___br___data.meta.update(meta)
         return ___br___data
 
-    def process(self, data: ByteStr) -> Union[Optional[ByteStr], Generator[ByteStr, None, None]]:
+    def process(self, data: Chunk, /) -> Union[Optional[ByteStr], Generator[ByteStr, None, None]]:
         return data
 
     @classmethod
@@ -2363,5 +2325,5 @@ class Unit(UnitBase, abstract=True):
 
 __pdoc__ = {
     'Unit.is_reversible': Executable.is_reversible.__doc__,
-    'Unit.codec': Executable.codec.__doc__
+    'Unit.codec': Executable.codec.__doc__,
 }
