@@ -1,5 +1,5 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
+from __future__ import annotations
+
 from refinery.units import Unit, RefineryPartialResult
 
 
@@ -7,7 +7,7 @@ class zstd(Unit):
     """
     ZStandard (ZSTD) compression and decompression.
     """
-    @Unit.Requires('pyzstd', 'all')
+    @Unit.Requires('pyzstd', ['all'])
     def _pyzstd():
         import pyzstd
         return pyzstd
@@ -24,5 +24,5 @@ class zstd(Unit):
         return zc.compress(data) + zc.flush()
 
     @classmethod
-    def handles(self, data: bytearray) -> bool:
+    def handles(cls, data: bytearray) -> bool:
         return data[:4] == B'\x28\xB5\x2F\xFD'
