@@ -1,5 +1,5 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
+from __future__ import annotations
+
 from Cryptodome.Cipher import ARC4
 
 from refinery.units.crypto.cipher import StandardCipherUnit, Arg
