@@ -1,5 +1,5 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
+from __future__ import annotations
+
 from typing import Sequence, Tuple
 from refinery.units.crypto.cipher.tea import TEAWithRounds, TEAUnit, BlockCipherFactory
 
