@@ -1,5 +1,3 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 """
 A package containing several sub-packages for various data formats.
 """
@@ -7,15 +5,15 @@ from __future__ import annotations
 
 import abc
 import collections
+import codecs
 import fnmatch
-import os
 import re
 
 from zlib import adler32
 from collections import Counter
 from typing import ByteString, Iterable, Callable, List, Union, Optional
 
-from refinery.units import Arg, Unit, RefineryPartialResult, RefineryPotentialUserError
+from refinery.units import Arg, Unit, Chunk, RefineryPartialResult, RefineryPotentialUserError
 from refinery.lib.meta import metavars, ByteStringWrapper, LazyMetaOracle
 from refinery.lib.xml import XMLNodeBase
 from refinery.lib.tools import exception_to_string
@@ -121,9 +119,7 @@ class PathExtractorUnit(Unit, abstract=True):
         list: Arg.Switch('-l',
             help='Return all matching paths as UTF8-encoded output chunks.') = False,
         join_path: Arg.Switch('-j', group='PATH', help=(
-            'Join path names with the previously existing one. If the previously existing path has '
-            'a file extension, it is removed. Then, if that path already exists on disk, a numeric '
-            'extension is appended to avoid conflict with the file system.')) = False,
+            'Join path names with the previously existing one.')) = False,
         drop_path: Arg.Switch('-d', group='PATH',
             help='Do not modify the path variable for output chunks.') = False,
         fuzzy: Arg.Counts('-z', group='MATCH', help=(
@@ -167,7 +163,7 @@ class PathExtractorUnit(Unit, abstract=True):
                     if len(t) >= 0x1000:
                         raise OverflowError
                     if not isinstance(t, str):
-                        t = t.decode(self.codec)
+                        t = codecs.decode(t, self.codec)
                 except Exception as E:
                     raise RefineryPotentialUserError(
                         F'Invalid path pattern of length {len(t)}.') from E
@@ -185,10 +181,10 @@ class PathExtractorUnit(Unit, abstract=True):
         ]
 
     @abc.abstractmethod
-    def unpack(self, data: ByteString) -> Iterable[UnpackResult]:
+    def unpack(self, data: Chunk) -> Iterable[UnpackResult]:
         raise NotImplementedError
 
-    def process(self, data: ByteString) -> ByteString:
+    def process(self, data: Chunk) -> ByteString:
         meta = metavars(data)
         results: List[UnpackResult] = list(self.unpack(data))
 
@@ -200,12 +196,6 @@ class PathExtractorUnit(Unit, abstract=True):
         root = ''
         uuid = 0
 
-        def path_exists(p: str):
-            try:
-                return os.path.exists(p) and not os.path.isdir(p)
-            except Exception:
-                return False
-
         def get_data(result: UnpackResult):
             try:
                 data = result.get_data()
@@ -247,13 +237,6 @@ class PathExtractorUnit(Unit, abstract=True):
                 root = str(ByteStringWrapper(meta[metavar], self.codec))
             except KeyError:
                 pass
-            if path_exists(root):
-                root, _, rest = root.rpartition('.')
-                root = root or rest
-            _rr = root
-            _rk = 1
-            while path_exists(root):
-                root = F'{_rr}.{_rk}'
 
         for result in results:
             path = normalize(result.path)
