@@ -1,5 +1,3 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 from __future__ import annotations
 from typing import List, Optional, Type
 
@@ -31,11 +29,12 @@ class xt(ArchiveUnit, docs='{0}{p}{PathExtractorUnit}'):
         # units that check fixed offsets
         from refinery.units.formats.archive.xttar import xttar        ; yield xttar     # noqa
         from refinery.units.formats.archive.xtiso import xtiso        ; yield xtiso     # noqa
-        from refinery.units.formats.office.xtrtf import xtrtf         ; yield xtrtf     # noqa
+        from refinery.units.formats.archive.xtchm import xtchm        ; yield xtchm     # noqa
         from refinery.units.formats.archive.xtcab import xtcab        ; yield xtcab     # noqa
         from refinery.units.formats.archive.xtace import xtace        ; yield xtace     # noqa
         from refinery.units.formats.archive.xtmacho import xtmacho    ; yield xtmacho   # noqa
         from refinery.units.formats.archive.xtasar import xtasar      ; yield xtasar    # noqa
+        from refinery.units.formats.office.xtrtf import xtrtf         ; yield xtrtf     # noqa
         from refinery.units.formats.pdf import xtpdf                  ; yield xtpdf     # noqa
         from refinery.units.formats.winreg import winreg              ; yield winreg    # noqa
         from refinery.units.formats.archive.xtgz import xtgz          ; yield xtgz      # noqa
@@ -44,7 +43,6 @@ class xt(ArchiveUnit, docs='{0}{p}{PathExtractorUnit}'):
         from refinery.units.formats.msi import xtmsi                  ; yield xtmsi     # noqa
         # units that search for markers
         from refinery.units.formats.archive.xt7z import xt7z          ; yield xt7z      # noqa
-        from refinery.units.formats.office.xtdoc import xtdoc         ; yield xtdoc     # noqa
         from refinery.units.formats.archive.xtzip import xtzip        ; yield xtzip     # noqa
         from refinery.units.formats.pe.dotnet.dnsfx import dnsfx      ; yield dnsfx     # noqa
         from refinery.units.formats.archive.xtinno import xtinno      ; yield xtinno    # noqa
@@ -56,6 +54,7 @@ class xt(ArchiveUnit, docs='{0}{p}{PathExtractorUnit}'):
         from refinery.units.formats.archive.xtzpaq import xtzpaq      ; yield xtzpaq    # noqa
         from refinery.units.formats.email import xtmail               ; yield xtmail    # noqa
         from refinery.units.formats.office.xtone import xtone         ; yield xtone     # noqa
+        from refinery.units.formats.office.xtdoc import xtdoc         ; yield xtdoc     # noqa
         # units that implement more complex parsing / searching:
         from refinery.units.formats.archive.xtsim import xtsim        ; yield xtsim     # noqa
         from refinery.units.formats.archive.xtnuitka import xtnuitka  ; yield xtnuitka  # noqa
@@ -109,19 +108,22 @@ class xt(ArchiveUnit, docs='{0}{p}{PathExtractorUnit}'):
                         return
                     try:
                         test_unpack = not self.unit.args.list
-                        for item in unit.unpack(data):
-                            if test_unpack:
-                                item.get_data()
-                                test_unpack = False
-                            self.count += 1
-                            yield item
+                        for filtered in unit.filter([data]):
+                            for item in unit.unpack(filtered):
+                                if test_unpack:
+                                    item.get_data()
+                                    test_unpack = False
+                                self.count += 1
+                                yield item
                     except Exception as error:
                         if not self.fallback:
                             errors[handler.name] = error
                         if isinstance(error, MultipleArchives):
                             self.unit.log_warn(error)
                         else:
-                            self.unit.log_debug('handler unpacking failed:', error)
+                            if self.unit.log_debug():
+                                raise error
+                            self.unit.log_info('handler unpacking failed:', error)
                     else:
                         self.success = True
                 elif verdict is None:
