@@ -1,5 +1,5 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
+from __future__ import annotations
+
 from refinery.units.formats.archive import ArchiveUnit
 from refinery.lib.thirdparty import acefile
 from refinery.lib.structures import MemoryFile
@@ -10,7 +10,7 @@ class xtace(ArchiveUnit, docs='{0}{s}{PathExtractorUnit}'):
     Extract files from an ACE archive.
     """
     def unpack(self, data):
-        ace = acefile.open(MemoryFile(data, read_as_bytes=True))
+        ace = acefile.open(MemoryFile(data, output=bytes))
         for member in ace.getmembers():
             member: acefile.AceMember
             comment = {} if not member.comment else {'comment': member.comment}
