@@ -1,5 +1,5 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
+from __future__ import annotations
+
 from typing import Optional, Dict, Union, Type
 
 from refinery.units.formats.archive import ArchiveUnit, UnpackResult
