@@ -1,5 +1,5 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
+from __future__ import annotations
+
 import json
 from refinery.units import Unit
 
@@ -8,7 +8,7 @@ class dsphp(Unit):
     """
     Deserialize PHP serialized data and re-serialize as JSON.
     """
-    @Unit.Requires('phpserialize', 'formats')
+    @Unit.Requires('phpserialize', ['formats'])
     def _php():
         import phpserialize
         return phpserialize
