@@ -1,5 +1,5 @@
-#!/usr/bin/env python3
-# -*- coding: utf - 8 -* -
+from __future__ import annotations
+
 from refinery.units import Unit
 from refinery.lib.vfs import VirtualFileSystem
 
@@ -13,7 +13,7 @@ class evtx(Unit):
     def __init__(self, raw: Unit.Arg.Switch('-r', help='Extract raw event data rather than XML.') = False):
         super().__init__(raw=raw)
 
-    @Unit.Requires('python-evtx', 'formats')
+    @Unit.Requires('python-evtx', ['formats'])
     def _evtx():
         from Evtx.Evtx import Evtx
         return Evtx
