@@ -1,5 +1,5 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
+from __future__ import annotations
+
 from refinery.lib.inno.ifps import IFPSFile
 from refinery.units.formats.ifps import IFPSBase
 
@@ -15,5 +15,5 @@ class ifpsstr(IFPSBase):
             yield string.encode(self.codec)
 
     @classmethod
-    def handles(self, data: bytearray) -> bool:
+    def handles(cls, data: bytearray) -> bool:
         return data.startswith(IFPSFile.Magic)
