@@ -1,5 +1,3 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 from __future__ import annotations
 
 from typing import TYPE_CHECKING
@@ -17,7 +15,7 @@ class imgdb(Unit):
     Provides access to the direct bytes of an image file. Each row of pixels is emitted as an
     individual chunk.
     """
-    @Unit.Requires('Pillow', 'formats')
+    @Unit.Requires('Pillow', ['formats'])
     def _image():
         from PIL import Image
         return Image
@@ -30,7 +28,7 @@ class imgdb(Unit):
 
     def process(self, data):
         try:
-            image = self._image.open(MemoryFile(data, read_as_bytes=True))
+            image = self._image.open(MemoryFile(data, output=bytes))
         except Exception:
             raise ValueError('input could not be parsed as an image')
         test = image.getpixel((0, 0))
