@@ -1,5 +1,5 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
+from __future__ import annotations
+
 from refinery.units import Unit
 from refinery.lib.java import JvClassFile
 
@@ -14,5 +14,5 @@ class jvstr(Unit):
             yield string.encode(self.codec)
 
     @classmethod
-    def handles(self, data):
+    def handles(cls, data):
         return data[:4] == B'\xCA\xFE\xBA\xBE'
