@@ -1,5 +1,5 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
+from __future__ import annotations
+
 from refinery.units import Unit
 
 
@@ -8,7 +8,7 @@ class rtfc(Unit):
     Implements the RTF compression format. This compression algorithm is used, for example, to
     compress RTF data in Outlook messages.
     """
-    @Unit.Requires('compressed_rtf', 'formats', 'office', 'default', 'extended')
+    @Unit.Requires('compressed_rtf', ['formats', 'office', 'default', 'extended'])
     def _rtfc():
         import compressed_rtf
         return compressed_rtf
