@@ -1,5 +1,5 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
+from __future__ import annotations
+
 from refinery.units.formats import PathExtractorUnit, UnpackResult
 from refinery.lib.dotnet.header import DotNetHeader
 
