@@ -1,5 +1,3 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 from __future__ import annotations
 
 import itertools
@@ -182,7 +180,7 @@ class pemeta(Unit):
         )
 
     @classmethod
-    def handles(self, data):
+    def handles(cls, data):
         return data[:2] == B'MZ'
 
     @classmethod
