@@ -1,9 +1,9 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 """
 A simple tool to output binary data. Multiple arguments are output in framed
 format, see `refinery.lib.frame`.
 """
+from __future__ import annotations
+
 import os
 
 from refinery.units import Arg, Unit
