@@ -1,5 +1,5 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
+from __future__ import annotations
+
 from refinery.units.pattern import SingleRegexUnit
 from refinery.units.meta import ConditionalUnit
 
