@@ -1,5 +1,3 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 from __future__ import annotations
 
 import math
@@ -30,7 +28,7 @@ class iemap(Unit):
     ):
         super().__init__(label=' '.join(label), background=background, legend=legend, block_char=block_char)
 
-    @Unit.Requires('colorama', 'display', 'default', 'extended')
+    @Unit.Requires('colorama', ['display', 'default', 'extended'])
     def _colorama():
         import colorama
         return colorama
