@@ -1,5 +1,5 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
+from __future__ import annotations
+
 from refinery.units import Arg, Unit
 
 
@@ -28,7 +28,7 @@ class ppjscript(Unit):
             keep_escapes=keep_escapes,
         )
 
-    @Unit.Requires('jsbeautifier', 'display', 'extended')
+    @Unit.Requires('jsbeautifier', ['display', 'extended'])
     def _jsb():
         import jsbeautifier
         import jsbeautifier.unpackers.javascriptobfuscator
@@ -37,7 +37,7 @@ class ppjscript(Unit):
         jsbeautifier.unpackers.javascriptobfuscator.detect = lambda *_: False
         return jsbeautifier
 
-    def process(self, data: bytes):
+    def process(self, data: bytearray):
         if self.args.strip_comments:
             from refinery.units.obfuscation.js.comments import deob_js_comments
             code = data | deob_js_comments | str
