@@ -1,5 +1,5 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
+from __future__ import annotations
+
 from itertools import cycle, repeat, islice
 
 from refinery.units import Arg, Unit
